@@ -3,12 +3,9 @@ package My::Module::Build;
 use strict;
 use warnings;
 
-use Module::Build;
-our @ISA = qw{ Module::Build };
+use base qw{ Module::Build };
 
 use Carp;
-# use lib 'inc';	# Already done because this module is running.
-use My::Module::Recommend;
 
 
 sub ACTION_authortest {
@@ -16,13 +13,8 @@ sub ACTION_authortest {
 
     local $ENV{AUTHOR_TESTING} = 1;
 
-    my @depends_on = ( qw{ build } );
-    -e 'META.json' or push @depends_on, 'distmeta';
-    $self->depends_on( @depends_on );
-
-    $self->test_files( qw{ t xt/author },
-	My::Module::Recommend->make_optional_modules_tests(),
-    );
+    $self->depends_on( 'build' );
+    $self->test_files( qw{ t xt/author } );
     $self->depends_on( 'test' );
 
     return;
@@ -77,8 +69,7 @@ C<--test_files> argument.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -86,7 +77,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2021 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
