@@ -17,7 +17,7 @@ use PPIx::QuoteLike::Token::Unknown;
 use PPIx::QuoteLike::Token::Whitespace;
 use Scalar::Util ();
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use constant ARRAY	=> ref [];
 use constant CODE	=> ref sub {};
@@ -562,16 +562,18 @@ sub _link_elems {
 	if ( my $right = $matching_bracket{$left} ) {
 	    # Based on Regexp::Common $RE{balanced}
 	    return ( $cache{$left} =
-		qr{ (
+		# TODO replace (??{...}) with (?-1) once we can rely on
+		# at least Perl 5.009005.
+		qr/ (
 		    \Q$left\E
 		    (?:
 			(?> [^\\\Q$left$right\E]+ ) |
 			(?> \$ [\Q$left$right\E] ) |
 			(?> \\ . ) |
-			(?-1)
+			(??{$cache{$left}})
 		    )*
 		    \Q$right\E
-		) }smx
+		) /smx
 	    );
 	} else {
 	    # Based on Regexp::Common $RE{delimited}{-delim=>'`'}
